pub struct FileLockMonitoring {}Trait Implementations
Sourceimpl Debug for FileLockMonitoring
impl Debug for FileLockMonitoring
Sourceimpl Monitoring for FileLockMonitoring
impl Monitoring for FileLockMonitoring
Sourceimpl MonitoringBuilder<FileLockMonitoring> for Builder
impl MonitoringBuilder<FileLockMonitoring> for Builder
Sourcefn token(
self,
) -> Result<<FileLockMonitoring as Monitoring>::Token, MonitoringCreateTokenError>
fn token( self, ) -> Result<<FileLockMonitoring as Monitoring>::Token, MonitoringCreateTokenError>
Creates a new
MonitoringToken on success or returns a MonitoringCreateTokenError
on failure.Sourcefn monitor(
self,
) -> Result<<FileLockMonitoring as Monitoring>::Monitor, MonitoringCreateMonitorError>
fn monitor( self, ) -> Result<<FileLockMonitoring as Monitoring>::Monitor, MonitoringCreateMonitorError>
Instantiates a
MonitoringMonitor to monitor a MonitoringTokenSourcefn cleaner(
self,
) -> Result<<FileLockMonitoring as Monitoring>::Cleaner, MonitoringCreateCleanerError>
fn cleaner( self, ) -> Result<<FileLockMonitoring as Monitoring>::Cleaner, MonitoringCreateCleanerError>
Instantiates a
MonitoringCleaner. If it could be instantiated successfully the owner is
allowed to remove all stale resources from the former dead process.Sourceimpl NamedConceptBuilder<FileLockMonitoring> for Builder
impl NamedConceptBuilder<FileLockMonitoring> for Builder
Sourcefn new(name: &FileName) -> Self
fn new(name: &FileName) -> Self
Defines the name of the newly created
NamedConcept.Sourcefn config(
self,
config: &<FileLockMonitoring as NamedConceptMgmt>::Configuration,
) -> Self
fn config( self, config: &<FileLockMonitoring as NamedConceptMgmt>::Configuration, ) -> Self
Sets the custom configuration of the concept.
Sourceimpl NamedConceptMgmt for FileLockMonitoring
impl NamedConceptMgmt for FileLockMonitoring
type Configuration = Configuration
Sourcefn list_cfg(
cfg: &Self::Configuration,
) -> Result<Vec<FileName>, NamedConceptListError>
fn list_cfg( cfg: &Self::Configuration, ) -> Result<Vec<FileName>, NamedConceptListError>
Returns a list of all available concepts with a custom configuration.
Sourcefn does_exist_cfg(
name: &FileName,
cfg: &Self::Configuration,
) -> Result<bool, NamedConceptDoesExistError>
fn does_exist_cfg( name: &FileName, cfg: &Self::Configuration, ) -> Result<bool, NamedConceptDoesExistError>
Returns true if a concept with that name exists under a custom configuration, otherwise false
Sourceunsafe fn remove_cfg(
name: &FileName,
cfg: &Self::Configuration,
) -> Result<bool, NamedConceptRemoveError>
unsafe fn remove_cfg( name: &FileName, cfg: &Self::Configuration, ) -> Result<bool, NamedConceptRemoveError>
Removes an existing concept under a custom configuration. Returns true if the concepts
existed and was removed, if the concept did not exist it returns false. Read more
Sourcefn remove_path_hint(value: &Path) -> Result<(), NamedConceptPathHintRemoveError>
fn remove_path_hint(value: &Path) -> Result<(), NamedConceptPathHintRemoveError>
Removes the path hint directory. Will be realized only when the concept actually uses
the path hint.
Sourceunsafe fn remove(name: &FileName) -> Result<bool, NamedConceptRemoveError>
unsafe fn remove(name: &FileName) -> Result<bool, NamedConceptRemoveError>
Removes an existing concept. Returns true if the concepts existed and was removed,
if the concept did not exist it returns false. Read more
Sourcefn does_exist(name: &FileName) -> Result<bool, NamedConceptDoesExistError>
fn does_exist(name: &FileName) -> Result<bool, NamedConceptDoesExistError>
Returns true if a concept with that name exists, otherwise false
Sourcefn list() -> Result<Vec<FileName>, NamedConceptListError>
fn list() -> Result<Vec<FileName>, NamedConceptListError>
Returns a list of all available concepts with the default configuration.
Sourcefn default_prefix() -> FileName
fn default_prefix() -> FileName
The default prefix of every zero copy connection
Sourcefn default_path_hint() -> Path
fn default_path_hint() -> Path
The default path hint for every zero copy connection