pub struct Configuration { /* private fields */ }Trait Implementations
Sourceimpl Clone for Configuration
impl Clone for Configuration
Sourcefn clone(&self) -> Configuration
fn clone(&self) -> Configuration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Configuration
impl Debug for Configuration
Sourceimpl Default for Configuration
impl Default for Configuration
Sourceimpl NamedConceptConfiguration for Configuration
impl NamedConceptConfiguration for Configuration
Sourcefn get_prefix(&self) -> &FileName
fn get_prefix(&self) -> &FileName
Returns the configurations prefix.
Sourcefn get_suffix(&self) -> &FileName
fn get_suffix(&self) -> &FileName
Returns the configurations suffix.
Sourcefn path_hint(self, value: &Path) -> Self
fn path_hint(self, value: &Path) -> Self
Sets a path hint under which the underlying resources shall be stored. When the concept
uses resources like
iceoryx2_bb_posix::shared_memory::SharedMemory the path will be
ignored.Sourcefn get_path_hint(&self) -> &Path
fn get_path_hint(&self) -> &Path
Returns the configurations path hint.
Sourcefn path_for(&self, value: &FileName) -> FilePath
fn path_for(&self, value: &FileName) -> FilePath
Returns the full path for a given value under the given configuration.
Sourceimpl PartialEq for Configuration
impl PartialEq for Configuration
Sourcefn eq(&self, other: &Configuration) -> bool
fn eq(&self, other: &Configuration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for Configuration
impl StructuralPartialEq for Configuration