pub struct DynamicMemoryBuilder<Allocator, Shm: SharedMemory<Allocator>>where
Allocator: Debug + ShmAllocator,{ /* private fields */ }Trait Implementations
Sourceimpl<Allocator, Shm: Debug + SharedMemory<Allocator>> Debug for DynamicMemoryBuilder<Allocator, Shm>
impl<Allocator, Shm: Debug + SharedMemory<Allocator>> Debug for DynamicMemoryBuilder<Allocator, Shm>
Sourceimpl<Allocator: ShmAllocator, Shm: SharedMemory<Allocator>> NamedConceptBuilder<DynamicMemory<Allocator, Shm>> for DynamicMemoryBuilder<Allocator, Shm>
impl<Allocator: ShmAllocator, Shm: SharedMemory<Allocator>> NamedConceptBuilder<DynamicMemory<Allocator, Shm>> for DynamicMemoryBuilder<Allocator, Shm>
Sourcefn new(name: &FileName) -> Self
fn new(name: &FileName) -> Self
Defines the name of the newly created
NamedConcept.Sourcefn config(self, config: &Shm::Configuration) -> Self
fn config(self, config: &Shm::Configuration) -> Self
Sets the custom configuration of the concept.
Sourcefn max_chunk_layout_hint(self, value: Layout) -> Self
fn max_chunk_layout_hint(self, value: Layout) -> Self
Provides an initial hint to the underlying
ShmAllocator on how large the largest chunk
will be. If the chunk exceeds the hinted Layout a new SharedMemory segment is
acquired to satisfy the memory needs.Sourcefn max_number_of_chunks_hint(self, value: usize) -> Self
fn max_number_of_chunks_hint(self, value: usize) -> Self
Provides an initial hint to the underlying
ShmAllocator on how many chunks at most will
be used in parallel. If the number of chunk exceeds the hint a new SharedMemory segment
is acquired to satisfy the memory needs.Sourcefn allocation_strategy(self, value: AllocationStrategy) -> Self
fn allocation_strategy(self, value: AllocationStrategy) -> Self
Defines the
AllocationStrategy that is pursued when a new SharedMemory segment is
acquired.Sourcefn create(
self,
) -> Result<DynamicMemory<Allocator, Shm>, SharedMemoryCreateError>
fn create( self, ) -> Result<DynamicMemory<Allocator, Shm>, SharedMemoryCreateError>
Creates new
SharedMemory. If it already exists the method will fail.Auto Trait Implementations
impl<Allocator, Shm> !Freeze for DynamicMemoryBuilder<Allocator, Shm>
impl<Allocator, Shm> RefUnwindSafe for DynamicMemoryBuilder<Allocator, Shm>where
<Shm as NamedConceptMgmt>::Configuration: RefUnwindSafe,
<Allocator as ShmAllocator>::Configuration: RefUnwindSafe,
impl<Allocator, Shm> Send for DynamicMemoryBuilder<Allocator, Shm>
impl<Allocator, Shm> Sync for DynamicMemoryBuilder<Allocator, Shm>where
<Shm as NamedConceptMgmt>::Configuration: Sync,
<Allocator as ShmAllocator>::Configuration: Sync,
impl<Allocator, Shm> Unpin for DynamicMemoryBuilder<Allocator, Shm>where
<Shm as NamedConceptMgmt>::Configuration: Unpin,
<Allocator as ShmAllocator>::Configuration: Unpin,
impl<Allocator, Shm> UnsafeUnpin for DynamicMemoryBuilder<Allocator, Shm>where
<Shm as NamedConceptMgmt>::Configuration: UnsafeUnpin,
<Allocator as ShmAllocator>::Configuration: UnsafeUnpin,
impl<Allocator, Shm> UnwindSafe for DynamicMemoryBuilder<Allocator, Shm>where
<Shm as NamedConceptMgmt>::Configuration: UnwindSafe,
<Allocator as ShmAllocator>::Configuration: UnwindSafe,