pub struct DynamicView<Allocator: ShmAllocator, Shm: SharedMemory<Allocator>> { /* private fields */ }Trait Implementations
Sourceimpl<Allocator: ShmAllocator, Shm: SharedMemory<Allocator>> Abandonable for DynamicView<Allocator, Shm>
impl<Allocator: ShmAllocator, Shm: SharedMemory<Allocator>> Abandonable for DynamicView<Allocator, Shm>
Sourceimpl<Allocator: Debug + ShmAllocator, Shm: Debug + SharedMemory<Allocator>> Debug for DynamicView<Allocator, Shm>
impl<Allocator: Debug + ShmAllocator, Shm: Debug + SharedMemory<Allocator>> Debug for DynamicView<Allocator, Shm>
Sourceunsafe fn register_and_translate_offset(
&self,
offset: PointerOffset,
) -> Result<*const u8, SharedMemoryOpenError>
unsafe fn register_and_translate_offset( &self, offset: PointerOffset, ) -> Result<*const u8, SharedMemoryOpenError>
Registers a received
PointerOffset at the ResizableSharedMemoryView and returns the
absolut pointer to the data. If the segment of the received PointerOffset was not yet
mapped into the processes space, it will be opened and mapped. If this fails a
SharedMemoryOpenError is returned. Read moreSourceunsafe fn unregister_offset(&self, offset: PointerOffset)
unsafe fn unregister_offset(&self, offset: PointerOffset)
Unregisters a received
PointerOffset that was previously registered. Read moreSourcefn number_of_active_segments(&self) -> usize
fn number_of_active_segments(&self) -> usize
Returns the number of active
SharedMemory segments.Sourcefn timeout(self, value: Duration) -> Self
fn timeout(self, value: Duration) -> Self
The timeout defines how long the
SharedMemoryBuilder should wait for
SharedMemoryBuilder::create() to finialize
the initialization. This is required when the SharedMemory is created and initialized
concurrently from another process. By default it is set to Duration::ZERO for no
timeout.Sourcefn open(
self,
access_mode: AccessMode,
) -> Result<DynamicView<Allocator, Shm>, SharedMemoryOpenError>
fn open( self, access_mode: AccessMode, ) -> Result<DynamicView<Allocator, Shm>, SharedMemoryOpenError>
Opens already existing
SharedMemory. If it does not exist or the initialization is not
yet finished the method will fail.Auto Trait Implementations
impl<Allocator, Shm> !Freeze for DynamicView<Allocator, Shm>
impl<Allocator, Shm> !RefUnwindSafe for DynamicView<Allocator, Shm>
impl<Allocator, Shm> Send for DynamicView<Allocator, Shm>
impl<Allocator, Shm> !Sync for DynamicView<Allocator, Shm>
impl<Allocator, Shm> Unpin for DynamicView<Allocator, Shm>
impl<Allocator, Shm> UnsafeUnpin for DynamicView<Allocator, Shm>
impl<Allocator, Shm> UnwindSafe for DynamicView<Allocator, Shm>where
Shm: UnwindSafe + RefUnwindSafe,
<Shm as NamedConceptMgmt>::Configuration: UnwindSafe,
Allocator: UnwindSafe + RefUnwindSafe,