pub enum AllocationStrategy {
BestFit,
PowerOfTwo,
Static,
}Expand description
Describes generically an AllocationStrategy, meaning how the memory is increased when the
available memory is insufficient.
Variants
BestFit
Increases the memory so that it perfectly fits the new size requirements. This may lead to a lot of reallocations but has the benefit that no byte is wasted.
PowerOfTwo
Increases the memory by rounding the increased memory size up to the next power of two. Reduces reallocations a lot at the cost of increased memory usage.
Static
The memory is not increased. This may lead to an out-of-memory error when allocating.